@@ -1,5 +1,5 @@
 from __future__ import absolute_import, unicode_literals
-__version__ = '0.40'
+__version__ = '0.41'
 __license__ = 'MIT'
 
 import re
@@ -46,8 +46,6 @@ re_eng = re.compile('[a-zA-Z0-9]', re.U)
 re_han_default = re.compile("([\u4E00-\u9FD5a-zA-Z0-9+#&\._%\-]+)", re.U)
 
 re_skip_default = re.compile("(\r\n|\s)", re.U)
-re_han_cut_all = re.compile("([\u4E00-\u9FD5]+)", re.U)
-re_skip_cut_all = re.compile("[^a-zA-Z0-9+#\n]", re.U)
 
 def setLogLevel(log_level):
     global logger
@@ -200,15 +198,29 @@ class Tokenizer(object):
     def __cut_all(self, sentence):
         dag = self.get_DAG(sentence)
         old_j = -1
+        eng_scan = 0
+        eng_buf = u''
         for k, L in iteritems(dag):
+            if eng_scan==1 and not re_eng.match(sentence[k]):
+                eng_scan = 0
+                yield eng_buf
             if len(L) == 1 and k > old_j:
-                yield sentence[k:L[0] + 1]
+                if re_eng.match(sentence[k]):
+                    if eng_scan == 0:
+                        eng_scan = 1
+                        eng_buf = sentence[k]
+                    else:
+                        eng_buf += sentence[k]
+                if eng_scan == 0:
+                    yield sentence[k:L[0] + 1]
                 old_j = L[0]
             else:
                 for j in L:
                     if j > k:
                         yield sentence[k:j + 1]
                         old_j = j
+        if eng_scan==1:
+            yield eng_buf
 
     def __cut_DAG_NO_HMM(self, sentence):
         DAG = self.get_DAG(sentence)
@@ -285,10 +297,9 @@ class Tokenizer(object):
         '''
         is_paddle_installed = False
         if use_paddle == True:
-            import_paddle_check = import_paddle()
             is_paddle_installed = check_paddle_install()
         sentence = strdecode(sentence)
-        if use_paddle == True and is_paddle_installed == True and import_paddle_check == True:
+        if use_paddle == True and is_paddle_installed == True:
             if sentence is None or sentence == "" or sentence == u"":
                 yield sentence
                 return
@@ -299,12 +310,8 @@ class Tokenizer(object):
                     continue
                 yield sent
             return
-        if cut_all:
-            re_han = re_han_cut_all
-            re_skip = re_skip_cut_all
-        else:
-            re_han = re_han_default
-            re_skip = re_skip_default
+        re_han = re_han_default
+        re_skip = re_skip_default
         if cut_all:
             cut_block = self.__cut_all
         elif HMM:
